Changelog
=========


v31.1.0
-------

Add new convenience method InstallRequirement.get_pinned_version() to return
the pinned version if there is such thing.


v31.0.1
-------

Fix twine warning wrt. long_description content type.


v31.0.0
-------

Include code in wheel. This was not included otherwise.
Improve documentation


v30.0.0
-------

Initial release based on pip at commit 5cf98408f48a0ef91d61aea56485a7a83f6bbfa8
e.g., https://github.com/pypa/pip/tree/5cf98408f48a0ef91d61aea56485a7a83f6bbfa8
